@@ -9,6 +9,7 @@ from __future__ import (
     annotations,
 )
 
+import logging
 from typing import (
     Optional,
 )
@@ -23,6 +24,8 @@ from .abc import (
     Broker,
 )
 
+logger = logging.getLogger(__name__)
+
 
 class EventBroker(Broker):
     """Minos Event broker class."""
@@ -43,4 +46,5 @@ class EventBroker(Broker):
         if topic is None:
             topic = self.topic
         event = Event(topic, items)
-        return await self._send_bytes(event.topic, event.avro_bytes)
+        logger.info(f"Sending '{event!s}'...")
+        return await self.send_bytes(event.topic, event.avro_bytes)
